@@ -179,6 +179,12 @@ struct
   let a_onmousemove = Xml.mouse_event_handler_attrib "onmousemove"
   let a_onmouseout = Xml.mouse_event_handler_attrib "onmouseout"
 
+  (** Javascript touch events *)
+  let a_ontouchstart = Xml.touch_event_handler_attrib "ontouchstart"
+  let a_ontouchend = Xml.touch_event_handler_attrib "ontouchend"
+  let a_ontouchmove = Xml.touch_event_handler_attrib "ontouchmove"
+  let a_ontouchcancel = Xml.touch_event_handler_attrib "ontouchcancel"
+
   (** Javascript keyboard events *)
   let a_onkeypress = Xml.keyboard_event_handler_attrib "onkeypress"
   let a_onkeydown = Xml.keyboard_event_handler_attrib "onkeydown"
@@ -264,6 +270,8 @@ struct
 
   let a_maxlength = int_attrib "maxlength"
 
+  let a_minlength = int_attrib "minlength"
+
   let a_name = string_attrib "name"
 
   let a_autocomplete x =
@@ -470,6 +478,12 @@ struct
 
   let a_media = mediadesc_attrib "media"
 
+  (* ARIA *)
+
+  let a_role = space_sep_attrib "role"
+
+  let a_aria name = space_sep_attrib ("aria-" ^ name)
+
   type 'a elt = Xml.elt
 
   type ('a, 'b) nullary = ?a: (('a attrib) list) -> unit -> 'b elt
@@ -512,7 +526,8 @@ struct
 
   let nav = star "nav"
 
-  let pcdata = Xml.pcdata
+  let txt s = Xml.pcdata s
+  let pcdata = txt
 
   let entity = Xml.entity
 
@@ -797,6 +812,9 @@ struct
   type doc  = [ `Html ] elt
   let doc_toelt x = x
 
+  module I = Xml_stream.Import(Xml)
+  let of_seq s = totl @@ I.of_seq s
+
   module Unsafe = struct
 
     let data s = Xml.encodedpcdata s
@@ -853,6 +871,7 @@ struct
     | `Next -> "next"
     | `Nofollow -> "nofollow"
     | `Noreferrer -> "noreferrer"
+    | `Noopener -> "noopener"
     | `Pingback -> "pingback"
     | `Prefetch -> "prefetch"
     | `Prev -> "prev"
