@@ -22,15 +22,17 @@
 (** Signature of typesafe constructors for HTML documents. *)
 module type T = sig
 
+  open Html_types
+
   (** HTML elements.
 
       Element constructors are in section {{!elements}elements}. Most elements constructors
       are either {{!nullary}nullary}, {{!unary}unary} or {{!star}star},
       depending on the number of children they accept.
       Children are usually given as a list of elements.
-      {{!pcdata}pcdata} is used for text.
+      {{!txt}txt} is used for text.
 
-      [div [a [pcdata "Foo"]]]
+      [div [a [txt "Foo"]]]
       is equivalent to
       [<div><a>foo</a></div>]
 
@@ -48,14 +50,14 @@ module type T = sig
   type +'a elt
 
   (** A complete HTML document. *)
-  type doc = [ `Html ] elt
+  type doc = html elt
 
   (** HTML attributes
 
       Attribute constructors are in section {{!attributes}attributes} and their name starts
       with [a_]. Attributes are given to elements with the [~a] optional argument.
 
-      [a ~a:[a_href "ocsigen.org"] [pcdata "link!"]]
+      [a ~a:[a_href "ocsigen.org"] [txt "link!"]]
       is equivalent to
       [<a href="ocsigen.org">link!</a>]
 
@@ -120,8 +122,6 @@ module type T = sig
   (** Various information about HTML, such as the doctype, ... *)
   module Info : Xml_sigs.Info
 
-  open Html_types
-
   (** {3 Uri} *)
 
   type uri = Xml.uri
@@ -242,6 +242,12 @@ module type T = sig
   val a_onmousemove : Xml.mouse_event_handler -> [> | `OnMouseMove] attrib
   val a_onmouseout : Xml.mouse_event_handler -> [> | `OnMouseOut] attrib
 
+  (** {4 Touch events} *)
+  val a_ontouchstart : Xml.touch_event_handler -> [> | `OnTouchStart] attrib
+  val a_ontouchend : Xml.touch_event_handler -> [> | `OnTouchEnd] attrib
+  val a_ontouchmove : Xml.touch_event_handler -> [> | `OnTouchMove] attrib
+  val a_ontouchcancel : Xml.touch_event_handler -> [> | `OnTouchCancel] attrib
+
   (** {4 Keyboard events} *)
 
   val a_onkeypress : Xml.keyboard_event_handler -> [> | `OnKeyPress] attrib
@@ -476,6 +482,8 @@ module type T = sig
 
   val a_maxlength : number wrap -> [> | `Maxlength] attrib
 
+  val a_minlength : number wrap -> [> | `Minlength] attrib
+
   val a_method :
     [< | `Get | `Post] wrap -> [> | `Method] attrib
 
@@ -645,18 +653,42 @@ module type T = sig
 
   val a_property : string wrap -> [> | `Property] attrib
 
+  (** {3 {{: https://www.w3.org/TR/wai-aria-1.1/} WAI-ARIA} support} *)
+
+  (** {{: https://www.w3.org/TR/wai-aria-1.1/} WAI-ARIA} is a specification
+      written by the W3C, defining a set of additional HTML attributes that can
+      be applied to elements to provide additional semantics and improve
+      accessibility wherever it is lacking.
+
+      See for example a {{:
+      https://developer.mozilla.org/en-US/docs/Learn/Accessibility/WAI-ARIA_basics}
+      WAI-ARIA tutorial}.
+  *)
+
+  val a_role : string list wrap -> [> | `Role] attrib
+  (** @see <https://www.w3.org/TR/role-attribute> Role attribute specification
+      @see <https://www.w3.org/TR/wai-aria-1.1/#role_definitions> List of WAI-ARIA roles
+  *)
+
+  val a_aria : string -> string list wrap -> [> | `Aria] attrib
+  (** Basic support for WAI-ARIA attributes: [a_aria "foo"] corresponds to an
+      "aria-foo" attribute.
+
+      @see <https://www.w3.org/TR/wai-aria-1.1/#state_prop_def> List of WAI-ARIA attributes
+  *)
+
   (** {2:elements Elements} *)
 
-  val pcdata : string wrap -> [> | `PCDATA] elt
+  val txt : string wrap -> [> | txt] elt
 
   val html :
     ?a: ((html_attrib attrib) list) ->
-    [< | `Head] elt wrap -> [< | `Body] elt wrap -> [> | `Html] elt
+    [< | head] elt wrap -> [< | body] elt wrap -> [> | html] elt
   [@@reflect.element "html"]
 
   val head :
     ?a: ((head_attrib attrib) list) ->
-    [< | `Title] elt wrap -> (head_content_fun elt) list_wrap -> [> | head] elt
+    [< | title] elt wrap -> (head_content_fun elt) list_wrap -> [> | head] elt
   [@@reflect.element "head"]
 
   val base : ([< | base_attrib], [> | base]) nullary
@@ -671,10 +703,10 @@ module type T = sig
   (** {3 Section} *)
 
   val footer :
-    ([< | common], [< | flow5_without_header_footer], [> | `Footer]) star
+    ([< | footer_attrib], [< | footer_content_fun], [> | footer]) star
 
   val header :
-    ([< | common], [< | flow5_without_header_footer], [> | `Header]) star
+    ([< | header_attrib], [< | header_content_fun], [> | header]) star
 
   val section :
     ([< | section_attrib], [< | section_content_fun], [> | section]) star
@@ -738,7 +770,7 @@ module type T = sig
     ([< | figcaption_attrib], [< | figcaption_content_fun], [> | figcaption]) star
 
   val figure :
-    ?figcaption: ([`Top of [< `Figcaption ] elt wrap | `Bottom of [< `Figcaption ] elt wrap ]) ->
+    ?figcaption: ([`Top of [< | figcaption ] elt wrap | `Bottom of [< | figcaption ] elt wrap ]) ->
     ([< | figure_attrib], [< | figure_content_fun], [> | figure]) star
   [@@reflect.element "figure"]
 
@@ -765,7 +797,7 @@ module type T = sig
 
   val bdo :
     dir: [< | `Ltr | `Rtl] wrap ->
-    ([< | common], [< | phrasing], [> | `Bdo]) star
+    ([< | bdo_attrib], [< | bdo_content_fun], [> | bdo]) star
 
   val abbr : ([< | abbr_attrib], [< | abbr_content_fun], [> | abbr]) star
 
@@ -796,12 +828,12 @@ module type T = sig
 
   (** {3 Hypertext} *)
 
-  val a : ([< | a_attrib], 'a, [> | `A of 'a]) star
+  val a : ([< | a_attrib], 'a, [> | 'a a]) star
 
   (** {3 Edit} *)
 
-  val del : ([< | del_attrib], 'a, [> | `Del of 'a]) star
-  val ins : ([< | ins_attrib], 'a, [> | `Ins of 'a]) star
+  val del : ([< | del_attrib], 'a, [> | 'a del]) star
+  val ins : ([< | ins_attrib], 'a, [> | 'a ins]) star
 
   (** {3 Embedded} *)
 
@@ -811,27 +843,16 @@ module type T = sig
     ([< img_attrib], [> img]) nullary
 
   val iframe :
-    ([< | common | `Src | `Name | `Sandbox | `Seamless | `Width | `Height],
-     [< | `PCDATA], [> | `Iframe]) star
+    ([< | iframe_attrib], [< | iframe_content_fun], [> | iframe]) star
 
   val object_ :
-    ?params: (([< | `Param] elt) list_wrap ) ->
-    ([<
-      | common
-      | `Data
-      | `Form
-      | `Mime_type
-      | `Height
-      | `Width
-      | `Name
-      | `Usemap
-    ], 'a, [> | `Object of 'a ]) star
+    ?params: (([< | param] elt) list_wrap ) ->
+    ([< | object__attrib], 'a, [> | `Object of 'a]) star
   [@@reflect.element "object_" "object"]
 
   val param : ([< | param_attrib], [> | param]) nullary
 
-  val embed :
-    ([< | common | `Src | `Height | `Mime_type | `Width], [> | `Embed]) nullary
+  val embed : ([< | embed_attrib], [> | embed]) nullary
 
   val audio :
     ?src:Xml.uri wrap ->
@@ -861,9 +882,9 @@ module type T = sig
       | `Media
       | `Hreflang
       | `Mime_type
-    ], [> | `Area]) nullary
+    ], [> | area]) nullary
 
-  val map : ([< | map_attrib], 'a, [> | `A of 'a]) star
+  val map : ([< | map_attrib], 'a, [> | 'a map]) star
 
   (** {3 Tables Data} *)
 
@@ -911,9 +932,8 @@ module type T = sig
   val form : ([< | form_attrib], [< | form_content_fun], [> | form]) star
 
   val fieldset :
-    ?legend: [ | `Legend ] elt wrap ->
-    ([< | common | `Disabled | `Form | `Name], [< | flow5],
-     [> | `Fieldset]) star
+    ?legend: [< | legend ] elt wrap ->
+    ([< | fieldset_attrib], [< | fieldset_content_fun], [> | fieldset]) star
   [@@reflect.element "fieldset"]
 
   val legend :
@@ -938,14 +958,15 @@ module type T = sig
   val datalist :
     ?children:(
       [<
-        | `Options of ([< | `Option] elt) list_wrap
+        | `Options of ([< | selectoption] elt) list_wrap
         | `Phras of ([< | phrasing] elt) list_wrap
-      ]) -> ([< | common], [> | `Datalist]) nullary
+      ]) ->
+    ([< | datalist_attrib], [> | datalist]) nullary
   [@@reflect.element "datalist"]
 
   val optgroup :
     label: text wrap  ->
-    ([< | common | `Disabled | `Label], [< | `Option], [> | `Optgroup]) star
+    ([< | optgroup_attrib], [< | optgroup_content_fun], [> | optgroup]) star
 
   val option :
     ([< | option_attrib], [< | option_content_fun], [> | selectoption]) unary
@@ -972,20 +993,20 @@ module type T = sig
       @see <http://www.w3schools.com/html/html_entities.asp> A tutorial on HTML entities.
       @see <https://www.w3.org/TR/html5/syntax.html#named-character-references> The list of HTML entities.
   *)
-  val entity : string -> [> | `PCDATA] elt
+  val entity : string -> [> | txt] elt
 
-  val space : unit -> [> | `PCDATA] elt
+  val space : unit -> [> | txt] elt
 
-  val cdata : string -> [> | `PCDATA] elt
-  val cdata_script : string -> [> | `PCDATA] elt
-  val cdata_style : string -> [> | `PCDATA] elt
+  val cdata : string -> [> | txt] elt
+  val cdata_script : string -> [> | txt] elt
+  val cdata_style : string -> [> | txt] elt
 
 
   (** {3 Interactive} *)
 
   val details :
-    [< | `Summary] elt wrap ->
-    ([< | common | `Open], [< | flow5], [> | `Details]) star
+    [< | summary] elt wrap ->
+    ([< | details_attrib], [< | details_content_fun], [> | details]) star
   [@@reflect.element "details"]
 
   val summary :
@@ -993,21 +1014,15 @@ module type T = sig
 
   val command :
     label: text wrap ->
-    ([<
-      | common
-      | `Icon
-      | `Disabled
-      | `Checked
-      | `Radiogroup
-      | `Command_Type
-    ], [> | `Command]) nullary
+    ([< | command_attrib], [> | command]) nullary
 
   val menu :
     ?children:(
       [<
         | `Lis of ([< | `Li of [< | common]] elt) list_wrap
         | `Flows of ([< | flow5] elt) list_wrap
-      ]) -> ([< | common | `Label | `Menu_Type], [> | `Menu]) nullary
+      ]) ->
+    ([< | menu_attrib], [> | menu]) nullary
   [@@reflect.element "menu"]
 
   (** {3 Scripting} *)
@@ -1028,15 +1043,7 @@ module type T = sig
   val link :
     rel: linktypes wrap ->
     href: Xml.uri wrap ->
-    ([<
-      | common
-      | `Hreflang
-      | `Media
-      | `Rel
-      | `Href
-      | `Sizes
-      | `Mime_type
-    ], [> | `Link]) nullary
+    ([< | link_attrib], [> | link]) nullary
 
   (** {3 Ruby} *)
 
@@ -1046,7 +1053,23 @@ module type T = sig
 
   val ruby : ([< | ruby_attrib], [< | ruby_content_fun], [> | ruby]) star
 
-  (** {2 Conversion with untyped representation} *)
+  (** {3 Deprecated} *)
+
+  val pcdata : string wrap -> [> | pcdata] elt
+  [@@ocaml.deprecated "Use txt instead"]
+  (** @deprecated Use txt instead *)
+
+  (** {2 Conversion with untyped representation} 
+
+      WARNING: These functions do not ensure HTML or SVG validity! You should
+      always explicitly given an appropriate type to the output.
+  *)
+
+  (** [import signal] converts the given XML signal into Tyxml elements.
+      It can be used with HTML and SVG parsing libraries, such as Markup.
+      @raise Xml_stream.Malformed_stream if the stream is malformed.
+  *)
+  val of_seq : Xml_stream.signal Seq.t -> 'a elt list_wrap
 
   val tot : Xml.elt -> 'a elt
   val totl : Xml.elt list_wrap -> 'a elt list_wrap
@@ -1134,6 +1157,7 @@ sig
      and type Xml.event_handler = Xml.event_handler
      and type Xml.mouse_event_handler = Xml.mouse_event_handler
      and type Xml.keyboard_event_handler = Xml.keyboard_event_handler
+     and type Xml.touch_event_handler = Xml.touch_event_handler
      and type Xml.attrib = Xml.attrib
      and type Xml.elt = Xml.elt
      and module Svg := Svg
