@@ -118,6 +118,7 @@ type linktype =
     | `Next
     | `Nofollow
     | `Noreferrer
+    | `Noopener
     | `Pingback
     | `Prefetch
     | `Prev
@@ -170,6 +171,8 @@ type linktypes = linktype list
         Indicates that the current document's original author or publisher does not endorse the referenced document.}
         {- [`Noreferrer]:
         Requires that the user agent not send an HTTP Referer (sic) header if the user follows the hyperlink.}
+        {- [`Noopener]:
+        Instructs the browser to open the link without granting the new browsing context access to the document that opened it.}
         {- [`Pingback]:
         Gives the address of the pingback server that handles pingbacks to the current document.}
         {- [`Prefetch]:
@@ -328,6 +331,10 @@ type events =
     | `OnSubmit
     | `OnSuspend
     | `OnTimeUpdate
+    | `OnTouchStart
+    | `OnTouchEnd
+    | `OnTouchMove
+    | `OnTouchCancel
     | `OnVolumeChange
     | `OnWaiting
     | `OnKeyPress
@@ -339,8 +346,16 @@ type events =
     | `OnLoadStart
   ]
 
+(** {2 ARIA} *)
+
+type aria =
+  [
+    | `Role
+    | `Aria
+  ]
+
 (** Common attributes *)
-type common = [ | core | i18n | events ]
+type common = [ | core | i18n | events | aria ]
 
 (** {1 Categories of HTML elements}
 
@@ -1097,10 +1112,17 @@ type flow5_without_sectioning_heading_header_footer_address =
        flow5_without_media) transparent
   ]
 
+type flow5_without_sectioning_heading_header_footer =
+  [
+    | flow5_without_sectioning_heading_header_footer_address
+    | `Address
+  ]
+
 (*
   Type for HTML for elements
 *)
 type pcdata = [ | `PCDATA ]
+type txt = [ | `PCDATA ]
 
 type notag
 
@@ -1384,9 +1406,9 @@ type dd_attrib = [ | common ]
 (* NAME: dt, KIND: star, TYPE: [= common ], [= phrasing], [=`Dt], ARG: [= phrasing], ATTRIB:  OUT: [=`Dt] *)
 type dt = [ | `Dt ]
 
-type dt_content = [ | phrasing ]
+type dt_content = [ | flow5_without_sectioning_heading_header_footer ]
 
-type dt_content_fun = [ | phrasing ]
+type dt_content_fun = [ | flow5_without_sectioning_heading_header_footer ]
 
 type dt_attrib = [ | common ]
 
@@ -1994,6 +2016,7 @@ type input_attrib =
     | `List
     | `Input_Max
     | `Maxlength
+    | `Minlength
     | `Input_Min
     | `Multiple
     | `Name
@@ -2019,6 +2042,7 @@ type textarea_attrib =
     | `Disabled
     | `Form
     | `Maxlength
+    | `Minlength
     | `Name
     | `Placeholder
     | `ReadOnly
