@@ -199,7 +199,8 @@ struct
 
   let foreignObject ?a children = Xml.node ?a "foreignObject" children
 
-  let pcdata s = Xml.pcdata s
+  let txt s = Xml.pcdata s
+  let pcdata = txt
 
   (* generated *)
   let a_version = string_attrib "version"
@@ -696,6 +697,12 @@ struct
   let a_onmouseout = Xml.mouse_event_handler_attrib "onmouseout"
   let a_onmousemove = Xml.mouse_event_handler_attrib "onmousemove"
 
+  (** Javascript touch events *)
+  let a_ontouchstart = Xml.touch_event_handler_attrib "ontouchstart"
+  let a_ontouchend = Xml.touch_event_handler_attrib "ontouchend"
+  let a_ontouchmove = Xml.touch_event_handler_attrib "ontouchmove"
+  let a_ontouchcancel = Xml.touch_event_handler_attrib "ontouchcancel"
+
   let a_stop_color = color_attrib "stop-color"
 
   let a_stop_opacity = user_attrib C.string_of_number "stop-opacity"
@@ -888,6 +895,9 @@ struct
   type doc = [ `Svg ] elt
   let doc_toelt x = x
 
+  module I = Xml_stream.Import(Xml)
+  let of_seq s = totl @@ I.of_seq s
+
   module Unsafe = struct
 
     let data s = Xml.encodedpcdata s
