@@ -28,7 +28,7 @@ module type T = sig
       are either {{!nullary}nullary}, {{!unary}unary} or {{!star}star},
       depending on the number of children they accept.
       Children are usually given as a list of elements.
-      {{!pcdata}pcdata} is used for text.
+      {{!txt}txt} is used for text.
 
       The type variable ['a] is used to track the element's type. This
       allows the OCaml typechecker to check SVG validity.
@@ -682,9 +682,15 @@ module type T = sig
   val a_onmouseout : Xml.mouse_event_handler  -> [> | `OnMouseOut ] attrib
   val a_onmousemove : Xml.mouse_event_handler  -> [> | `OnMouseMove ] attrib
 
+  (** {3 Javascript touch events} *)
+  val a_ontouchstart : Xml.touch_event_handler -> [> | `OnTouchStart] attrib
+  val a_ontouchend : Xml.touch_event_handler -> [> | `OnTouchEnd] attrib
+  val a_ontouchmove : Xml.touch_event_handler -> [> | `OnTouchMove] attrib
+  val a_ontouchcancel : Xml.touch_event_handler -> [> | `OnTouchCancel] attrib
+
   (** {2:elements Elements} *)
 
-  val pcdata : string wrap -> [> | `PCDATA] elt
+  val txt : string wrap -> [> | txt] elt
 
   val svg : ([< | svg_attr], [< | svg_content], [> | svg]) star
 
@@ -949,7 +955,23 @@ module type T = sig
     ?a: ((foreignobject_attr attrib) list) ->
     Xml.elt list_wrap -> [> | foreignobject] elt
 
-  (** {2 Conversion with untyped representation} *)
+  (** {3 Deprecated} *)
+
+  val pcdata : string wrap -> [> txt] elt
+  [@@ocaml.deprecated "Use txt instead"]
+  (** @deprecated Use txt instead *)
+
+  (** {2 Conversion with untyped representation} 
+
+      WARNING: These functions do not ensure HTML or SVG validity! You should
+      always explicitly given an appropriate type to the output.
+  *)
+
+  (** [import signal] converts the given XML signal into Tyxml elements.
+      It can be used with HTML and SVG parsing libraries, such as Markup.
+      @raise Xml_stream.Malformed_stream if the stream is malformed.
+  *)
+  val of_seq : Xml_stream.signal Seq.t -> 'a elt list_wrap
 
   val tot : Xml.elt -> 'a elt
   val totl : Xml.elt list_wrap -> ('a elt) list_wrap
@@ -1034,6 +1056,7 @@ module Make (Xml : Xml_sigs.T) : sig
      and type Xml.event_handler = Xml.event_handler
      and type Xml.mouse_event_handler = Xml.mouse_event_handler
      and type Xml.keyboard_event_handler = Xml.keyboard_event_handler
+     and type Xml.touch_event_handler = Xml.touch_event_handler
      and type Xml.attrib = Xml.attrib
      and type Xml.elt = Xml.elt
 
