@@ -35,6 +35,7 @@ module type T = sig
   type event_handler
   type mouse_event_handler
   type keyboard_event_handler
+  type touch_event_handler
 
   type attrib
 
@@ -46,6 +47,7 @@ module type T = sig
   val event_handler_attrib : aname -> event_handler -> attrib
   val mouse_event_handler_attrib : aname -> mouse_event_handler -> attrib
   val keyboard_event_handler_attrib : aname -> keyboard_event_handler -> attrib
+  val touch_event_handler_attrib : aname -> touch_event_handler -> attrib
   val uri_attrib : aname -> uri wrap -> attrib
   val uris_attrib : aname -> uri list wrap -> attrib
 
@@ -189,7 +191,8 @@ module type Pp = sig
     Various implementations of [encode] are available in {!Xml_print}.
 *)
   val pp:
-    ?encode:(string -> string) -> unit -> Format.formatter -> elt -> unit
+    ?encode:(string -> string) -> ?indent:bool -> unit ->
+    Format.formatter -> elt -> unit
 end
 
 module type Typed_pp = sig
@@ -203,7 +206,8 @@ module type Typed_pp = sig
     Various implementations of [encode] are available in {!Xml_print}.
 *)
   val pp_elt :
-    ?encode:(string -> string) -> unit -> Format.formatter -> 'a elt -> unit
+    ?encode:(string -> string) -> ?indent:bool -> unit ->
+    Format.formatter -> 'a elt -> unit
 
 (** [pp ()] is a {!Format} printer for complete documents.
 
@@ -214,6 +218,7 @@ module type Typed_pp = sig
     Various implementations of [encode] are available in {!Xml_print}.
 *)
   val pp:
-    ?encode:(string -> string) -> ?advert:string -> unit -> Format.formatter -> doc -> unit
+    ?encode:(string -> string) -> ?indent:bool -> ?advert:string -> unit ->
+    Format.formatter -> doc -> unit
 
 end
